@@ -311,7 +311,7 @@ static void init_conf_items(void)
 	conf_items = ll_create();
 
 	item = calloc(1, sizeof(*item));
-	item->name = strdup("Interface");
+	item->name = strdup("Input");
 	item->type = t_sep;
 	ll_push(conf_items, "*", item);
 
@@ -331,6 +331,16 @@ static void init_conf_items(void)
 	item->list	= on_off_names;
 	ll_push(conf_items, "*", item);
 
+	item = calloc(1, sizeof(*item));
+	item->type = t_sep;
+	ll_push(conf_items, "*", item);
+
+	/* Scan */
+	item = calloc(1, sizeof(*item));
+	item->name = strdup("Scan");
+	item->type = t_sep;
+	ll_push(conf_items, "*", item);
+
 	item = calloc(1, sizeof(*item));
 	item->name	= strdup("Scan sort type");
 	item->cfname	= strdup("sort_order");
@@ -347,6 +357,16 @@ static void init_conf_items(void)
 	item->list	= on_off_names;
 	ll_push(conf_items, "*", item);
 
+	item = calloc(1, sizeof(*item));
+	item->type = t_sep;
+	ll_push(conf_items, "*", item);
+
+	/* Plot */
+	item = calloc(1, sizeof(*item));
+	item->name = strdup("Plot");
+	item->type = t_sep;
+	ll_push(conf_items, "*", item);
+
 	item = calloc(1, sizeof(*item));
 	item->name	= strdup("Statistics updates");
 	item->cfname	= strdup("stat_updates");
