@@ -251,8 +251,6 @@ struct scan_result {
 	pthread_mutex_t   mutex;
 };
 
-extern void init_scan_list(struct scan_result *sr);
-extern void free_scan_list(struct scan_entry *head);
 extern void *do_scan(void *sr_ptr);
 
 /*
