@@ -34,7 +34,12 @@
 #include <ctype.h>
 #include <math.h>
 #include <stdbool.h>
+#ifdef HAVE_LIBNCURSESW
+#define _XOPEN_SOURCE_EXTENDED
+#include <ncursesw/curses.h>
+#else
 #include <ncurses.h>
+#endif
 
 #include "llist.h"
 
